<?php

/**
 * OpenKM, Open Knowledge Management System S.L.  (http://www.openkm.com)
 * Copyright (c) 2006-2018
 *
 * No bytes were intentionally harmed during the development of this application.
 *
 * This program is commercial software; you can use it under the terms of the
 * EULA - OpenKM SDK End User License Agreement as published by OpenKM Knowledge Management System S.L.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * EULA - OpenKM SDK End User License Agreement for more details:
 * http://docs.openkm.com/kcenter/view/licenses/eula-openkm-sdk-end-user-license-agreement.html
 */

namespace openkm\definition;

/**
 * BaseWorkflow
 *
 * @author sochoa
 */
interface BaseWorkflow {

    public function registerProcessDefinition($content);

    public function deleteProcessDefinition($pdId);

    public function getProcessDefinition($pdId);

    public function runProcessDefinition($pdId, $uuid, $formElements = []);

    public function findAllProcessDefinitions();

    public function findProcessInstances($pdId);

    public function findLatestProcessDefinitions();

    public function findLastProcessDefinition($name);

    public function getProcessInstance($piId);

    public function findUserTaskInstances();

    public function findTaskInstances($piId);

    public function setTaskInstanceValues($tiId, $transName, $formElements = []);

    public function getTaskInstance($tiId);

    public function setTaskInstanceActorId($tiId, $actorId);

    public function startTaskInstance($tiId);

    public function endTaskInstance($tiId, $transName);

    public function getProcessDefinitionForms($pdId);
}

?>
